# WebAuthNEnrollment

An object used for enrolling the user in the Time-based One-time Password method for Multi-factor authentication. This is based on the WebAuthN standard defined here https://www.w3.org/TR/webauthn/#enumdef-userverificationrequirement
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**metadata** | [**MetadataWithId**](MetadataWithId.md) |  | [optional] 
**spec** | [**WebAuthNEnrollmentSpec**](WebAuthNEnrollmentSpec.md) |  | 
**status** | [**WebAuthNEnrollmentStatus**](WebAuthNEnrollmentStatus.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


